==> aerogear-security-1.2.0-source-release.zip: aerogear-security-1.2.0/src/main/java/org/jboss/aerogear/security/web/filter/SecureHeadersConfig.java <==
/**
 * JBoss, Home of Professional Open Source
 * Copyright Red Hat, Inc., and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.aerogear.security.web.filter;

import javax.servlet.FilterConfig;

public class SecureHeadersConfig {

    private final Long maxAge;
    private final Boolean includeSubDomains;
    private final String location;
    private String frameOptions;

    public SecureHeadersConfig(FilterConfig config) {
        this.maxAge = Long.valueOf(config.getInitParameter("max-age"));
        this.includeSubDomains = Boolean.valueOf(config.getInitParameter("include-subdomains"));
        this.location = config.getInitParameter("Location");
        this.frameOptions = config.getInitParameter("x-frame-options");
    }

    public String getMaxAge() {
        String header = "max-age=" + maxAge;
        if (includeSubDomains) {
            header += "; includeSubdomains";
        }
        return header;
    }

    public String getLocation() {
        return location;
    }

    public String getFrameOptions() {
        return frameOptions;
    }

    public boolean hasMaxAge() {
        return maxAge != null && maxAge >= 0;
    }

    public boolean hasLocation() {
        return isEmpty(location);
    }

    public boolean hasFrameOptions() {
        return isEmpty(frameOptions);
    }

    private boolean isEmpty(String value) {
        return value != null && !value.trim().isEmpty();
    }
}

==> aerogear-security-1.3.1-source-release.zip: aerogear-security-1.3.1/src/main/java/org/jboss/aerogear/security/web/filter/SecureHeadersConfig.java <==
/**
 * JBoss, Home of Professional Open Source
 * Copyright Red Hat, Inc., and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.aerogear.security.web.filter;

import javax.servlet.FilterConfig;

/**
 * HTTP headers related to security
 * For example: HSTS and Clickjacking mitigation support
 */
public class SecureHeadersConfig {

    private final Long maxAge;
    private final Boolean includeSubDomains;
    private final String location;
    private String frameOptions;

    public SecureHeadersConfig(FilterConfig config) {
        this.maxAge = Long.valueOf(config.getInitParameter("max-age"));
        this.includeSubDomains = Boolean.valueOf(config.getInitParameter("include-subdomains"));
        this.location = config.getInitParameter("Location");
        this.frameOptions = config.getInitParameter("x-frame-options");
    }

    /**
     * Specifies the number of seconds, after the reception of the STS header field
     * @see <a href="https://tools.ietf.org/html/rfc6797#section-6.1.1">The max-age Directive</a>
     * @return max-age directive
     */
    public String getMaxAge() {
        String header = "max-age=" + maxAge;
        if (includeSubDomains) {
            header += "; includeSubdomains";
        }
        return header;
    }

    /**
     * Retrieve the Location header
     * @see <a href="https://tools.ietf.org/html/rfc6797#section-7.2">HTTP Request Type</a>
     * @return Location header field value
     */
    public String getLocation() {
        return location;
    }

    /**
     * Allows a secure web page from host B to declare
     * that its content (for example a button, links, text, etc.) must not
     * be displayed in a frame (<frame> or <iframe>) of another page (e.g.
     * from host A).  In principle this is done by a policy declared in the
     * HTTP header and enforced by conforming browser implementations
     * @see <a href="https://tools.ietf.org/html/draft-ietf-websec-x-frame-options-02#section-1"> X-Frame-Options</a>
     * @return X-Frame-Options HTTP header field
     */
    public String getFrameOptions() {
        return frameOptions;
    }

    /**
     * Verify if the option "max-age" is present
     * @return boolean
     */
    public boolean hasMaxAge() {
        return maxAge != null && maxAge >= 0;
    }

    /**
     * Verify if the option "Location" is present
     * @return boolean
     */
    public boolean hasLocation() {
        return isEmpty(location);
    }

    /**
     * Verify if "x-frame-options" is present
     * @return boolean
     */
    public boolean hasFrameOptions() {
        return isEmpty(frameOptions);
    }

    private boolean isEmpty(String value) {
        return value != null && !value.trim().isEmpty();
    }
}
